@@ -1,18 +1,18 @@
-from sklearn.linear_model import LogisticRegression
-from micromlgen.utils import jinja
+from micromlgen.utils import jinja, check_type
 
 
 def is_logisticregression(clf):
     """Test if classifier can be ported"""
-    return isinstance(clf, LogisticRegression)
+    return check_type(clf, 'LogisticRegression')
 
 
 def port_logisticregression(clf, **kwargs):
-    """Port sklearn's DecisionTreeClassifier"""
-    kwargs['classname'] = kwargs['classname'] or 'LogisticRegression'
+    """Port sklearn's LogisticRegressionClassifier"""
     return jinja('logisticregression/logisticregression.jinja', {
         'weights': clf.coef_,
         'intercept': clf.intercept_,
         'classes': clf.classes_,
         'n_classes': len(clf.classes_)
+    }, {
+        'classname': 'LogisticRegression'
     }, **kwargs)
\ No newline at end of file
