@@ -9,7 +9,7 @@ from micromlgen.gaussiannb import is_gaussiannb, port_gaussiannb
 from micromlgen.pca import is_pca, port_pca
 from micromlgen.principalfft import is_principalfft, port_principalfft
 from micromlgen.linear_regression import is_linear_regression, port_linear_regression
-
+from micromlgen.xgboost import is_xgboost, port_xgboost
 
 def port(
         clf,
@@ -40,4 +40,6 @@ def port(
         return port_principalfft(**locals(), **kwargs)
     elif is_linear_regression(clf):
         return port_linear_regression(**locals(), **kwargs)
+    elif is_xgboost(clf):
+        return port_xgboost(**locals(), **kwargs)
     raise TypeError('clf MUST be one of %s' % ', '.join(platforms.ALLOWED_CLASSIFIERS))
\ No newline at end of file
