@@ -7,7 +7,6 @@ ALL = [
 
 ALLOWED_CLASSIFIERS = [
     'SVC',
-    'LinearSVC',
     'OneClassSVC',
     'RVC',
     'SEFR',
@@ -17,5 +16,6 @@ ALLOWED_CLASSIFIERS = [
     'LogisticRegression',
     'PCA',
     'PrincipalFFT',
-    'LinearRegression'
+    'LinearRegression',
+    'XGBClassifier'
 ]
\ No newline at end of file
